@@ -284,6 +284,13 @@ class SwerveDrivetrain(Subsystem):
             self.n_11.get_node_position()
         )
 
+        module_states = (
+            self.n_00.get_node_state(),
+            self.n_01.get_node_state(),
+            self.n_10.get_node_state(),
+            self.n_11.get_node_state(),
+        )
+
         self.odometry.update(
             self.get_heading(),
             *module_positions
@@ -293,7 +300,7 @@ class SwerveDrivetrain(Subsystem):
             self.get_heading(),
             module_positions
         )
-        self.chassis_speeds = self.kinematics.toChassisSpeeds(*module_positions)
+        self.chassis_speeds = self.kinematics.toChassisSpeeds(*module_states)
 
     def stop(self):
         """
